bayespy.inference.vmp.nodes.expfamily.ExponentialFamily.initialize_from_random
==============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.expfamily

.. automethod:: ExponentialFamily.initialize_from_random